JavaTokenType

Enum JavaTokenType 

pub enum JavaTokenType {
Show 113 variants Whitespace, LineComment, BlockComment, Identifier, StringLiteral, CharacterLiteral, IntegerLiteral, FloatingPointLiteral, BooleanLiteral, NullLiteral, Abstract, Assert, Boolean, Break, Byte, Case, Catch, Char, Class, Const, Continue, Default, Do, Double, Else, Enum, Extends, Final, Finally, Float, For, If, Goto, Implements, Import, Instanceof, Int, Interface, Long, Native, New, Package, Private, Protected, Public, Record, Return, Short, Static, Strictfp, Struct, Super, Switch, Synchronized, This, Throw, Throws, Transient, Try, Void, Volatile, While, Plus, PlusPlus, PlusEquals, Minus, MinusMinus, MinusEquals, Asterisk, AsteriskEquals, Slash, SlashEquals, Percent, PercentEquals, Assign, Equals, Bang, BangEquals, LessThan, LessThanEquals, LeftShift, LeftShiftEquals, GreaterThan, GreaterThanEquals, RightShift, RightShiftEquals, UnsignedRightShift, UnsignedRightShiftEquals, Ampersand, AmpersandAmpersand, AmpersandEquals, Pipe, PipePipe, PipeEquals, Caret, CaretEquals, Tilde, Question, Colon, Semicolon, Comma, Dot, Ellipsis, LeftParen, RightParen, LeftBrace, RightBrace, LeftBracket, RightBracket, At, DoubleColon, Error, EndOfFile,
}
Java token type.

Variants



Whitespace

Whitespace.



LineComment

Line comment.



BlockComment

Block comment.



Identifier

Identifier.



StringLiteral

String literal.



CharacterLiteral

Character literal.



IntegerLiteral

Integer literal.



FloatingPointLiteral

Floating point literal.



BooleanLiteral

Boolean literal.



NullLiteral

Null literal.



Abstract

abstract keyword.



Assert

assert keyword.



Boolean

boolean keyword.



Break

break keyword.



Byte

byte keyword.



Case

case keyword.



Catch

catch keyword.



Char

char keyword.



Class

class keyword.



Const

const keyword.



Continue

continue keyword.



Default

default keyword.



Do

do keyword.



Double

double keyword.



Else

else keyword.



Enum

enum keyword.



Extends

extends keyword.



Final

final keyword.



Finally

finally keyword.



Float

float keyword.



For

for keyword.



If

if keyword.



Goto

goto keyword.



Implements

implements keyword.



Import

import keyword.



Instanceof

instanceof keyword.



Int

int keyword.



Interface

interface keyword.



Long

long keyword.



Native

native keyword.



New

new keyword.



Package

package keyword.



Private

private keyword.



Protected

protected keyword.



Public

public keyword.



Record

record keyword.



Return

return keyword.



Short

short keyword.



Static

static keyword.



Strictfp

strictfp keyword.



Struct

struct keyword.



Super

super keyword.



Switch

switch keyword.



Synchronized

synchronized keyword.



This

this keyword.



Throw

throw keyword.



Throws

throws keyword.



Transient

transient keyword.



Try

try keyword.



Void

void keyword.



Volatile

volatile keyword.



While

while keyword.



Plus

+ operator.



PlusPlus

++ operator.



PlusEquals

+= operator.



Minus

- operator.



MinusMinus

-- operator.



MinusEquals

-= operator.



Asterisk

* operator.



AsteriskEquals

*= operator.



Slash

/ operator.



SlashEquals

/= operator.



Percent

% operator.



PercentEquals

%= operator.



Assign

= operator.



Equals

== operator.



Bang

! operator.



BangEquals

!= operator.



LessThan

< operator.



LessThanEquals

<= operator.



LeftShift

<< operator.



LeftShiftEquals

<<= operator.



GreaterThan

> operator.



GreaterThanEquals

>= operator.



RightShift

>> operator.



RightShiftEquals

>>= operator.



UnsignedRightShift

>>> operator.



UnsignedRightShiftEquals

>>>= operator.



Ampersand

& operator.



AmpersandAmpersand

&& operator.



AmpersandEquals

&= operator.



Pipe

| operator.



PipePipe

|| operator.



PipeEquals

|= operator.



Caret

^ operator.



CaretEquals

^= operator.



Tilde

~ operator.



Question

? operator.



Colon

: delimiter.



Semicolon

; delimiter.



Comma

, delimiter.



Dot

. delimiter.



Ellipsis

... delimiter.



LeftParen

( delimiter.



RightParen

) delimiter.



LeftBrace

{ delimiter.



RightBrace

} delimiter.



LeftBracket

[ delimiter.



RightBracket

] delimiter.



At

@ delimiter.



DoubleColon

:: delimiter.



Error

Error token.



EndOfFile

End of file token.

Implementations

Source

impl JavaTokenType

pub fn is_keyword(&self) -> bool

Returns true if the token type is a Java keyword.